#!/usr/bin/perl -w

use strict;
use Date::Calc;
use LWP::UserAgent;

# set the Date::Calc language
Date::Calc::Language(Date::Calc::Decode_Language('English'));

my $self          = 'list-teamstats-files.pl';
my $version       = '0.1';
my $verbose       = 1; # default: 0
my $download      = 1; # default: 1

# action: 
# - list 
# - show $team_id
# - files $team_id
my $action = 'list'; 

my $teamstats_baseurl = 'http://fah-web.stanford.edu/teamstats/';

my ($year,$month,$day,$hour,$min,$sec) = Date::Calc::Today_and_Now();

$month = '0'.$month if(length($month) == 1);
$day   = '0'.$day   if(length($day)   == 1);
$hour  = '0'.$hour  if(length($hour)  == 1);
$min   = '0'.$min   if(length($min)   == 1);
$sec   = '0'.$sec   if(length($sec)   == 1);

my $date = "$year-$month-$day";
my $time = "$hour:$min:$sec";
		
my %stats_of;

if($download == 1) {
	my $ua  = LWP::UserAgent->new();
  	   $ua->agent("$self/$version");
	   
	print "Downloading URL: $teamstats_baseurl ... " if($verbose);
	
	my $req = HTTP::Request->new(GET => $teamstats_baseurl);
	my $res = $ua->request($req);
	if($res->is_success) {
		print "Success\n" if($verbose);
		
		my $data = $res->content;
		
		my $i = 0;
		foreach(split /\r?\n/, $data) {
			#<IMG SRC="/icons/text.gif" ALT="[TXT]"> <A HREF="team0.html">team0.html</A>              04-Mar-2006 06:02  12.6M
			#<IMG SRC="/icons/text.gif" ALT="[TXT]"> <A HREF="team0.txt">team0.txt</A>               04-Mar-2006 06:02   4.0M
			if(/^\<IMG.*?\>\s*<A .*?HREF="(.*?)".*?>team(\d+)\.(html|txt)\<\/A\>\s*(\d+-\w+-\d+ \d+:\d+)?\s*((\d+\.\d+|\d+)[a-zA-Z])/) {
				#print "URL: $1  Team: $2  Type: $3  Date: $4  Size: $5\n";
				
				my $url   = $1;
				my $team  = $2;
				my $type  = $3;
				my $mtime = $4;
				my $size  = $5;
				
				#15-Nov-2005 12:35 
				if($mtime =~ /(\d{2})-(\w{3})-(\d{4}) (\d{2}):(\d{2})/) {
					my $day   = $1;
					my $month = $2;
					my $year  = $3;
					my $hour  = $4;
					my $min   = $5;

					$month = Date::Calc::Decode_Month($month);
					$month = '0'.$month if(length($month) == 1);

					$mtime = "$year-$month-$day $hour:$min";
				}
				
				$stats_of{$team}{file}{$type}{url}   = $teamstats_baseurl.$url;
				$stats_of{$team}{file}{$type}{mtime} = $mtime;
				$stats_of{$team}{file}{$type}{size}  = $size;

				$i++;
			}
			else {
				#print "FAILED: $_\n";
			}
		}

		if($i > 0) {
			print "Total teams: ";
			print ($i / 2);
			print "\n";
			print "Total files: $i\n";
			print "\n";

			foreach my $team (sort { $a <=> $b } keys %stats_of) {
				print "Team : $team\n";
				
				foreach my $type (sort { $a cmp $b } keys %{$stats_of{$team}{file}}) {
					print " ";
					printf("%4s", $type);
					print ": ";
					print $stats_of{$team}{file}{$type}{url};
					print " " if($type eq 'txt');
					print " ";
					print $stats_of{$team}{file}{$type}{mtime};
					print " (";
					print $stats_of{$team}{file}{$type}{size};
					print ")";
					print "\n";
				}
				print "\n";
			}
		}
		else {
			print "No files found at: $teamstats_baseurl\n";
		}
	}
	else {
		print "Failed!\n" if($verbose);
		print "Error: Failed to retrieve URL! ($teamstats_baseurl)\n";
		print "Server returned: ".$res->code." ".$res->message."\n";
	
		exit 1;
	}
}

